/*
 * midi_source.h
 * Copyright (C) 2004 Michael Natterer <mitch@gimp.org>
 *                    Simon Budig <simon@gimp.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __MIDI_SOURCE_H__
#define __MIDI_SOURCE_H__

#define MIDI_TYPE_SOURCE            (midi_source_get_type ())
#define MIDI_SOURCE(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), MIDI_TYPE_SOURCE, MidiSource))
#define MIDI_SOURCE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), MIDI_TYPE_SOURCE, MidiSourceClass))
#define MIDI_IS_SOURCE(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), MIDI_TYPE_SOURCE))
#define MIDI_IS_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), MIDI_TYPE_SOURCE))


typedef struct _MidiEvent       MidiEvent;
typedef struct _MidiSource      MidiSource;
typedef struct _MidiSourceClass MidiSourceClass;

typedef enum   _MidiEventType   MidiEventType;

enum _MidiEventType
{
  MIDI_EVENT_NOTEON,
  MIDI_EVENT_NOTEOFF,
  MIDI_EVENT_CONTROLLER,
};

struct _MidiEvent
{
  MidiEventType type;
  gint          channel;
  gint          note;
  gdouble       value;
};

struct _MidiSource
{
  GObject         parent_instance;

  gchar          *state;
  gchar          *device;
  gint            midi_channel;

  GIOChannel     *io;
  guint           io_id;

#ifdef HAVE_ALSA
  snd_seq_t      *sequencer;
  guint           seq_id;
#endif

  /* midi status */
  gboolean        swallow;
  gint            command;
  gint            channel;
  gint            key;
  gint            velocity;
  gint            msb;
  gint            lsb;
};

struct _MidiSourceClass
{
  GObjectClass  parent_class;

  /*  signals  */
  void   (* event)           (MidiSource      *midi_source,
                              const MidiEvent *event);

};

GType midi_source_get_type (void) G_GNUC_CONST;


#endif  /* __MIDI_SOURCE_H__ */

